<?php

/**
 * @version		$Id$
 * @author		NooTheme
 * @package		Joomla.Site
 * @subpackage	plg_system_nootabs
 * @copyright	Copyright (C) 2013 NooTheme. All rights reserved.
 * @license		License GNU General Public License version 2 or later; see LICENSE.txt, see LICENSE.php
 */
// no direct access
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');
require_once JPATH_SITE . '/components/com_content/helpers/route.php';

class plgSystemNootabs extends JPlugin {

	public function plgSystemNootab(&$subject, $config) {
		parent::__construct($subject, $config);
	}

	public function onAfterRender() {
		$app = JFactory::getApplication();
		if ($app->isAdmin())
			return;
		$_body = JResponse::getBody();
		if (JString::strpos($_body, '{nootabs')) {
			$_body = $this->parse($_body);
		}
		JResponse::setBody($_body);
	}

	public function parse($content) {
		$regex = '#{nootabs([^}]*)}([^{]*){/nootabs}#m';
		$output = preg_replace_callback($regex, array($this, 'parseTabs'), $content);
		return $output;
	}

	public function parseTabs(&$matches) {
		$params = array();
		$params = $this->parseParams($matches[1]);
		if (isset($params['type'])) {
			switch ($params['type']) {
				case 'modules':
					return $this->parseModules($params);
				case 'module':
					return $this->parseModule($params);
				case 'articles':
					return $this->parseArticles($params);
			}
		}
		return;
	}

	public function parseModule($params) {
		$moduleArr = array();
		if (isset($params['modulename']) && $params['modulename']) {
			$moduleArr = explode(',', trim($params['modulename']));
		}
		$rand = rand();
		$control = '';
		$content = '';
		$show = isset($params['show']) && is_numeric($params['show']) ? $params['show'] : 0;
		$k = 0;
		for ($i = 0; $i < count($moduleArr); $i++) {
			$module = JModuleHelper::getModule(substr(trim($moduleArr[$i]), 4));
			if ($module && $module->id) {
				$mparams = new JRegistry();
				$mparams->loadString($module->params);
				$class = ($k == $show ? ' active' : '');
				$control .="<li class=\"{$class}\"><a href=\"#nootab-{$rand}{$i}\" title=\"{$module->title}\" data-toggle=\"tab\">{$module->title}</a></li>";
				$content .="<div class=\"tab-pane {$class}\" id=\"nootab-{$rand}{$i}\">" . JModuleHelper::renderModule($module) . "</div>";
				$k++;
			}
		}
		return $this->toHtml($control, $content, $params, $rand);
	}

	public function parseModules($params) {
		$control = '';
		$content = '';
		$rand = rand();
		$show = isset($params['show']) && is_numeric($params['show']) ? $params['show'] : 0;
		if (isset($params['module'])) {
			$modules = JModuleHelper::getModules(trim($params['module']));
			for ($i = 0; $i < count($modules); $i++) {
				$mparams = new JRegistry();
				$mparams->loadString($modules[$i]->params);
				$clssfx = $mparams->get('moduleclass_sfx', '');
				$class = ($i == $show ? ' active' : '');
				$control .="<li class=\"{$class}\"><a href=\"#nootab-{$rand}{$i}\" title=\"{$modules[$i]->title}\" data-toggle=\"tab\">{$modules[$i]->title}</a></li>";
				$content .="<div class=\"tab-pane {$class}\" id=\"nootab-{$rand}{$i}\">" . JModuleHelper::renderModule($modules[$i]) . "</div>";
			}
		}
		return $this->toHtml($control, $content, $params, $rand);
	}

	public function parseArticles($params) {
		$articles = array();
		if (isset($params['ids'])) {
			$articles = $this->_getArticles($params['ids']);
		} elseif (isset($params['catid'])) {
			if (!isset($params['maxitems']) || $params['maxitems'] <= 0 || !is_numeric($params['maxitems']))
				$params['maxitems'] = 0;
			$articles = $this->_getArticles('', $params['catid'], $params['maxitems']);
		}
		$rand = rand();
		$control = '';
		$content = '';
		$show = isset($params['show']) && is_numeric($params['show']) ? $params['show'] : 0;
		$readmore = isset($params['readmore']) ? $params['readmore'] : true;
		for ($i = 0; $i < count($articles); $i++) {
			$class = ($i == $show ? ' active' : '');
			$control .="<li class=\"{$class}\"><a href=\"#nootab-{$rand}{$i}\" title=\"{$articles[$i]->title}\" data-toggle=\"tab\">{$articles[$i]->title}</a></li>";
			$content .="<div class=\"tab-pane {$class}\" id=\"nootab-{$rand}{$i}\">";
			if ($params['view'] == 'fulltext') {
				$content .= JHtml::_('content.prepare', $articles[$i]->introtext . $articles[$i]->fulltext);
			} else {
				$content .= JHtml::_('content.prepare', $articles[$i]->introtext);
			}
			if ($readmore) {
				$content .= "<br/><a class='readmore' href=\"{$articles[$i]->link}\" title='" . JText::_('Read more') . "'>" . JText::_('Read more') . "</a>";
			}
			$content .= "</div>";
		}

		return $this->toHtml($control, $content, $params, $rand);
	}

	protected function _getArticles($articleId = '', $catId = '', $limit = 0) {
		$app = JFactory::getApplication();
		JModelLegacy::addIncludePath(JPATH_SITE . '/components/com_content/models', 'ContentModel');
		$db = JFactory::getDbo();
		// Get an instance of the generic articles model
		$model = JModelLegacy::getInstance('Articles', 'ContentModel', array('ignore_request' => true));
		// Set application parameters in model
		$appParams = JFactory::getApplication()->getParams();
		$model->setState('params', $appParams);

		$model->setState('list.select', 'a.id, a.title, a.alias, a.introtext, a.fulltext, a.state, a.catid, a.created, a.created_by, a.created_by_alias,' . // use created if modified is 0
				'CASE WHEN a.modified = 0 THEN a.created ELSE a.modified END as modified,' . 'a.modified_by, uam.name as modified_by_name,' . // use created if publish_up is 0
				'CASE WHEN a.publish_up = 0 THEN a.created ELSE a.publish_up END as publish_up,' . 'a.publish_down, a.attribs, a.metadata, a.metakey, a.metadesc, a.access,' . 'a.hits, a.xreference, a.featured,' . ' LENGTH(a.fulltext) AS readmore');

		// Set the filters based on the module params
		$model->setState('list.start', 0);
		if ($catId != '' && $limit > 0) {
			$model->setState('list.limit', $limit);
		}
		$model->setState('filter.published', 1);

		// Access filter
		$access = !JComponentHelper::getParams('com_content')->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		$model->setState('filter.access', $access);

		// Category filter
		if ($catId) {
			$model->setState('filter.category_id', explode(',', $catId));
		}
		if ($articleId) {
			$model->setState('filter.article_id', explode(',', $articleId));
		}

		// Set ordering
		$model->setState('list.ordering', 'a.ordering');
		$model->setState('list.direction', '');

		$items = $model->getItems();

		if (count($items)) {
			foreach ($items as &$item) {
				$item->slug = $item->id . ':' . $item->alias;
				$item->catslug = $item->catid . ':' . $item->category_alias;

				if ($access || in_array($item->access, $authorised)) {
					// We know that user has the privilege to view the article
					$item->link = JRoute::_(ContentHelperRoute::getArticleRoute($item->slug, $item->catslug));
				} else {
					$item->link = JRoute::_('index.php?option=com_users&view=login');
				}
				$item->introtext = JHtml::_('content.prepare', $item->introtext);
				$item->fulltext = JHtml::_('content.prepare', $item->fulltext);
			}
		}

		return $items;
	}

	/**
	 * Method render a tab position
	 * 
	 * @param string $position
	 */
	public function toHtml($control, $content, $params, $rand) {

		$idtab = 'nooTabs-' . $rand;
		$cls = isset($params['class']) ? trim($params['class']) : '';

		$style = '';
		if (isset($params['width']) || isset($params['height'])) {
			$width = isset($params['width']) && is_numeric($params['width']) && $params['width'] > 0 ? 'width:' . $params['width'] . 'px' : '';
			$height = isset($params['height']) && is_numeric($params['height']) && $params['height'] > 0 ? 'height:' . $params['height'] . 'px' : '';
			$style = "style=\"{$width};{$height}\"";
		}
		$html = "<div id=\"nooTab{$idtab}\"  class=\"nootab {$cls}\" {$style}>
    		<ul class=\"nav nav-tabs\" id=\"{$idtab}\">{$control}</ul>
    		<div id=\"{$idtab}Content\" class=\"tab-content\">{$content}</div>
    		</div>";
		return $html;
	}

	public function parseParams($string) {
		$string = html_entity_decode($string, ENT_QUOTES);
		$regex = "/\s*([^=\s]+)\s*=\s*('([^']*)'|\"([^\"]*)\"|([^\s]*))/";
		$tabParams = null;
		if (preg_match_all($regex, $string, $matches)) {
			for ($i = 0; $i < count($matches[1]); $i++) {
				$key = $matches[1][$i];
				$value = $matches[3][$i] ? $matches[3][$i] : ($matches[4][$i] ? $matches[4][$i] : $matches[5][$i]);
				$tabParams[$key] = $value;
			}
		}
		return $tabParams;
	}

}